CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
71 lines
2.2 KiB
C++
71 lines
2.2 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip_test_kernels.hh>
|
|
|
|
#define THREADS_PER_BLOCK 512
|
|
|
|
HIP_TEST_CASE(Unit_hipGraphKernelNodeGetAttribute_Negative_Parameters) {
|
|
constexpr int N = 1024;
|
|
|
|
int *A_d, *B_d, *C_d;
|
|
HIP_CHECK(hipMalloc(&A_d, sizeof(int) * N));
|
|
HIP_CHECK(hipMalloc(&B_d, sizeof(int) * N));
|
|
HIP_CHECK(hipMalloc(&C_d, sizeof(int) * N));
|
|
|
|
hipGraph_t graph;
|
|
HIP_CHECK(hipGraphCreate(&graph, 0));
|
|
|
|
hipKernelNodeParams node_params{};
|
|
node_params.func = reinterpret_cast<void*>(HipTest::vectorADD<int>);
|
|
node_params.gridDim = dim3(N / THREADS_PER_BLOCK, 1, 1);
|
|
node_params.blockDim = dim3(THREADS_PER_BLOCK, 1, 1);
|
|
|
|
size_t N_elem{N};
|
|
void* kernel_params[] = {&A_d, &B_d, &C_d, reinterpret_cast<void*>(&N_elem)};
|
|
node_params.kernelParams = reinterpret_cast<void**>(kernel_params);
|
|
|
|
hipGraphNode_t graph_node;
|
|
HIP_CHECK(hipGraphAddKernelNode(&graph_node, graph, nullptr, 0, &node_params));
|
|
|
|
hipKernelNodeAttrValue node_attribute;
|
|
|
|
SECTION("node == nullptr") {
|
|
HIP_CHECK_ERROR(hipGraphKernelNodeGetAttribute(
|
|
nullptr, hipKernelNodeAttributeAccessPolicyWindow, &node_attribute),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("node is not a kernel node") {
|
|
hipGraphNode_t empty_node;
|
|
HIP_CHECK(hipGraphAddEmptyNode(&empty_node, graph, nullptr, 0));
|
|
HIP_CHECK_ERROR(hipGraphKernelNodeGetAttribute(
|
|
empty_node, hipKernelNodeAttributeAccessPolicyWindow, &node_attribute),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("invalid attribute") {
|
|
HIP_CHECK_ERROR(hipGraphKernelNodeGetAttribute(graph_node, static_cast<hipKernelNodeAttrID>(-1),
|
|
&node_attribute),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
#if HT_AMD // segfaults on NVIDIA
|
|
SECTION("value == nullptr") {
|
|
HIP_CHECK_ERROR(hipGraphKernelNodeGetAttribute(
|
|
graph_node, hipKernelNodeAttributeAccessPolicyWindow, nullptr),
|
|
hipErrorInvalidValue);
|
|
}
|
|
#endif
|
|
|
|
HIP_CHECK(hipGraphDestroy(graph));
|
|
|
|
HIP_CHECK(hipFree(A_d));
|
|
HIP_CHECK(hipFree(B_d));
|
|
HIP_CHECK(hipFree(C_d));
|
|
}
|